@@ -66,6 +66,8 @@ class Solution:
         self.libs = []
         self.libpath = []
         self.depend_libs = []
+        self.external_libs = []
+        self.external_libpath = []
         self.org_defines = {}
         self.defines = {}
         self.ASFLAGS = []
@@ -281,11 +283,23 @@ class Solution:
             for path in component.build_config.libpath:
                 if path not in self.libpath:
                     self.libpath.append(path)
+                if path not in self.external_libpath:
+                    self.external_libpath.append(path)
 
             # libs
             for lib in component.build_config.libs:
                 if lib not in self.libs:
                     self.libs.append(lib)
+                if lib not in self.external_libs:
+                    self.external_libs.append(lib)
+
+        # external libs changed need to relink
+        for lib in self.external_libs:
+            for path in self.external_libpath:
+                filename = os.path.join(path, 'lib' + lib + '.a')
+                if os.path.exists(filename):
+                    self.depend_libs.append(filename)
+                    break
 
         self.toolchain_prefix = solution_hw_info.toolchain_prefix
         self.ld_script = solution_hw_info.ld_script
