@@ -61,6 +61,9 @@ exist in the manifest.
         else:
             jobs = 4
 
+        # sync .repo first
+        yoc.sync_manifest()
+
         components = ComponentGroup()
         for component in yoc.components:
             if len(args) > 0:
